@@ -2,14 +2,12 @@ package Acme::Ford::Prefect2;
 
 use strict;
 use warnings;
+use XSLoader;
 
 # ABSTRACT: Test Module for Alien::Base + Alien::Build
-our $VERSION = '2.1100'; # VERSION
+our $VERSION = '2.2900'; # VERSION
 
-require DynaLoader;
-our @ISA = 'DynaLoader';
-__PACKAGE__->bootstrap($VERSION);
-$VERSION = eval $VERSION;
+XSLoader::load(__PACKAGE__, $VERSION);
 
 1;
 
@@ -25,7 +23,7 @@ Acme::Ford::Prefect2 - Test Module for Alien::Base + Alien::Build
 
 =head1 VERSION
 
-version 2.1100
+version 2.2900
 
 =head1 SYNOPSIS
 
@@ -70,7 +68,7 @@ L<Acme::Alien::DontPanic2>
 
 =head1 SOURCE REPOSITORY
 
-L<http://github.com/Perl5-Alien/Acme-Ford-Prefect2>
+L<http://github.com/PerlAlien/Acme-Ford-Prefect2>
 
 =head1 AUTHORS
 
